@@ -20,6 +20,7 @@
 # or see http://www.r-project.org/Licenses/GPL-2
 
 print.LKinfo <- function(x, ...) {
+#  print( x$call)
     LKinfo <- x
     L <- LKinfo$nlevel
     cat("Classes for this object are: " , class( LKinfo), fill=TRUE)
@@ -27,9 +28,13 @@ print.LKinfo <- function(x, ...) {
     cat("The second class usually will indicate the geometry
      e.g.  2-d rectangle is  LKRectangle", fill=TRUE)
     cat(" ", fill = TRUE) 
-    
+    cat("Some details on spatial autoregression flags:",     fill=TRUE)
+    cat( "stationary: ",  attr( LKinfo$a.wght,"stationary"),  fill=TRUE)
+    cat("first order (by level): ",  attr( LKinfo$a.wght,"first.order"), fill=TRUE)
+    cat("isotropic: "  ,   attr( LKinfo$a.wght,"isotropic"),   fill=TRUE)
+    cat(" ", fill = TRUE)
     if(LKinfo$dense){
-      cat("Hey, the dense flag is TRUE so computations will
+      cat("Hey! The dense flag is TRUE so computations will
           not be done using sparse matrices.", fill=TRUE)
     }
     cat("Ranges of locations in raw scale:", fill=TRUE)
@@ -41,6 +46,9 @@ print.LKinfo <- function(x, ...) {
     	print( LKinfo$latticeInfo$grid.info$range)
     }
     cat(" ", fill = TRUE)
+    cat("Logical (collapseFixedEffect) if fixed effects will be pooled:" ,
+        LKinfo$collapseFixedEffect, fill = TRUE)
+    cat(" ", fill = TRUE)
     cat("Number of levels:", L, fill = TRUE)
     cat("delta scalings:", x$latticeInfo$delta, fill = TRUE)
     cat("with an overlap parameter of ", LKinfo$basisInfo$overlap, fill=TRUE)
@@ -48,8 +56,16 @@ print.LKinfo <- function(x, ...) {
     if (!is.null(x$nu)) {
         cat("based on smoothness nu = ", x$nu, fill = TRUE)
     }
+    if(!is.null( x$alphaObject)){ 
+      cat("alpha specified at each level by objects: ",fill=TRUE)
+      cat("Level ", "Class", fill=TRUE)
+      for( level in 1:L){
+               cat( level, class(x$alphaObject[[1]]), fill=TRUE )
+      }
+    }
     temp<- unlist(x$a.wght)
     
+    cat(" ", fill = TRUE)
     if( length( temp)<= x$nlevel * 9){
     cat("a.wght: ", temp, fill = TRUE)
     }
@@ -60,6 +76,13 @@ print.LKinfo <- function(x, ...) {
       cat(" Level", k,
           dim(x$a.wght[[k]]), fill=TRUE )
       }
+    }
+    if(!is.null( x$a.wghtObject)){ 
+      cat("a.wght specified at each level by objects: ",fill=TRUE)
+      cat("Level ", "Class", fill=TRUE)
+      for( level in 1:L){
+        cat( level, class(x$a.wghtObject[[1]]), fill=TRUE )
+      }
     }
        cat(" ", fill = TRUE)
   # Details on basis functions at each level
